﻿using Google.Type;
using Hotline.Application.Knowledge;
using Hotline.FlowEngine.Notifies;
using Hotline.KnowledgeBase;
using Hotline.Settings;
using Hotline.Share.Enums.KnowledgeBase;
using MediatR;
using XF.Domain.Exceptions;

namespace Hotline.Application.Handlers.FlowEngine;

public class EndWorkflowHandler : INotificationHandler<EndWorkflowNotify>
{
    private readonly IKnowApplication _knowApplication;

    public EndWorkflowHandler(IKnowApplication knowApplication)
    {
        _knowApplication = knowApplication;
    }

    /// <summary>Handles a notification</summary>
    /// <param name="notification">The notification</param>
    /// <param name="cancellationToken">Cancellation token</param>
    public async Task Handle(EndWorkflowNotify notification, CancellationToken cancellationToken)
    {
        //知识审批收到此消息表示审批通过
        var workflow = notification.Workflow;
        switch (workflow.ModuleCode)
        {
            case WorkflowModuleConsts.KnowledgeAdd://新增
            case WorkflowModuleConsts.KnowledgeUpdate://修改
            case WorkflowModuleConsts.KnowledgeDelete://删除
                await _knowApplication.EndWorkKnowledge(workflow, cancellationToken);
                break;
        }
    }
}