﻿using Hotline.FlowEngine.Workflows;
using Hotline.Share.Dtos.FlowEngine;
using MediatR;
using XF.Domain.Entities;

namespace Hotline.FlowEngine.Notifies;

public record WorkflowNotify(Workflow Workflow, EFlowAssignType FlowAssignType, List<IdName> Handlers) : INotification;

/// <summary>
/// 开始流程
/// </summary>
public record StartWorkflowNotify(Workflow Workflow, EFlowAssignType FlowAssignType, List<IdName> Handlers, BasicWorkflowDto Dto) : WorkflowNotify(Workflow, FlowAssignType, Handlers);

/// <summary>
/// 节点办理完成
/// </summary>
public record NextStepNotify(Workflow Workflow, EFlowAssignType FlowAssignType, List<IdName> Handlers, BasicWorkflowDto Dto, bool IsCountersignStart, bool IsCountersignEnd) : WorkflowNotify(Workflow, FlowAssignType, Handlers);

/// <summary>
/// 接办
/// </summary>
/// <param name="Workflow"></param>
public record AcceptWorkflowNotify(Workflow Workflow) : INotification;

/// <summary>
/// 会签结束
/// </summary>
/// <param name="Workflow"></param>
public record CountersignEndAssigned(Workflow Workflow) : INotification;

/// <summary>
/// 退回上一节点
/// </summary>
/// <param name="Data"></param>
public record PreviousStepNotify(PreviousWorkflowDto Data) : INotification;

/// <summary>
/// 流程结束
/// </summary>
/// <param name="Workflow"></param>
public record EndWorkflowNotify(Workflow Workflow) : INotification;